# videojs-fetch-flv

用于下载 http-flv 流的 videojs 插件




## 安装

```sh
npm install --save videojs-fetch-flv
```

Other

```sh
npm install --save video.js videojs-flvjs flv.js

# or 

npm install --save video.js videojs-flvjs-es6 flv.js
```



## 用法

要在您的网站或 Web 应用程序中包含 videojs-fetch-flv，请使用以下任何方法。

### `<script>` Tag

这是最简单的情况。以您喜欢的任何方式获取脚本，并在包含[video.js](http://videojs.com/)*后*包含插件，以便全局可用。`videojs`

```html
<script src="//path/to/video.min.js"></script>
<script src="//path/to/flv.min.js"></script>
<script src="//path/to/videojs-flvjs.min.js"></script>
<script src="//path/to/videojs-fetch-flv.min.js"></script>
<script>
  var player = videojs('my-video')
  player.fetchFlv()
</script>
```

or

```html
<script src="//path/to/video.min.js"></script>
<script src="//path/to/flv.min.js"></script>
<script src="//path/to/videojs-flvjs.min.js"></script>
<script src="//path/to/videojs-fetch-flv.min.js"></script>
<script>
  var player = videojs('my-video')
  var options = {
    isLive: false,
    ...
  }
  player.fetchFlv(options)
</script>
```

or 

```html
<script src="//path/to/video.min.js"></script>
<script src="//path/to/flv.min.js"></script>
<script src="//path/to/videojs-flvjs.min.js"></script>
<script src="//path/to/videojs-fetch-flv.min.js"></script>
<script>
  var options = {
        plugins: {
          fetchFlv: {
            isLive: false,
            ...
          }
        }
      }
  var player = videojs('my-video', options)
</script>
```

### ES Modules

`import`像安装任何其他模块一样，通过 npm 和插件安装 videojs-fetch-flv 。您还需要以某种方式导入样式表。

```js
import videojs from 'video.js'
import 'videojs-fetch-flv'
import 'videojs-fetch-flv/dist/videojs-fetch-flv.css'

const player = videojs('my-video')
player.fetchFlv()
// player.fetchFlv({
//   isLive: true
// })
```

or

```js
import videojs from 'video.js'
import 'videojs-flvjs-es6'
import 'videojs-fetch-flv'
import 'videojs-fetch-flv/dist/videojs-fetch-flv.css'

const options = {
        plugins: {
          fetchFlv: {
            isLive: false,
            ...
          }
        }
      }
const player = videojs('my-video', options)
```


### Browserify/CommonJS

与 Browserify 一起使用时，通过 npm 和`require`插件安装 videojs-fetch-flv，就像安装任何其他模块一样。

```js
var videojs = require('video.js')

// The actual plugin function is exported by this module, but it is also
// attached to the `Player.prototype`; so, there is no need to assign it
// to a variable.
require('videojs-fetch-flv')

var player = videojs('my-video')
player.fetchFlv()
```

### RequireJS/AMD

与 RequireJS（或其他 AMD 库）一起使用时，以您喜欢的任何方式获取脚本，并`require`像往常一样获取插件：

```js
require(['video.js', 'videojs-fetch-flv'], function(videojs) {
  var player = videojs('my-video')
  player.fetchFlv()
})
```



## 方法



### show()

显示录制按钮控件



### hide()

隐藏录制按钮控件



### updateIsLive(value)

更新 options.isLive 值



### start()

当播放器在播放时，您可以手动录制。

```js
player.on('play', () => {
  player.fetchFlv().start()
})
```



### stop()

在播放器播放时，您可以手动停止录制并下载录制文件。

**注意：**关闭或销毁播放器时，如果正在录制，最好先调用stop()

```js
player.on('error', () => {
  player.fetchFlv().stop(isSaveFile)
})
```

isSaveFile: Boolean, default **false**

- **true**: 停止获取并保存媒体文件
- **false**: 仅停止获取



## 配置

| 属性          | 必要性 | 类型    | 默认值               | 说明                                                         |
| :------------ | :----: | ------- | -------------------- | ------------------------------------------------------------ |
| isLive        | 可选的 | Boolean | true                 | 下载参数。true用于下载http-flv，false用于浏览器直接下载      |
| beforeElement | 可选的 | String  | fullscreenMenuToggle | 之前要附加的按钮的 player.controlBar 组件的名称              |
| controlText   | 可选的 | String  | Download             | 控制按钮标题的字符串                                         |
| position      | 可选的 | String  | top-right            | 放置记录状态 div 的位置 (top-left, top-right, bottom-left, or bottom-right) |
| opacity       | 可选的 | Number  | 1                    | 记录状态 div 的不透明度（来自`[0, 1]`）。如果未指定，则默认为 1。 |



## License

MIT. Copyright (c) lin557


[videojs]: http://videojs.com/

